@@ -3,7 +3,7 @@
 ** Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
 ** Author:      Ulrich Telle
 ** Created:     2005-07-14
-** Copyright:   (c) 2005-2023 Ulrich Telle
+** Copyright:   (c) 2005-2024 Ulrich Telle
 ** License:     LGPL-3.0+ WITH WxWindows-exception-3.1
 */
 
@@ -46,6 +46,57 @@
 
 <dl>
 
+<dt><b>4.9.11</b> - <i>June 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.6 (SQLite version 3.46.0)</i>
+
+</dd>
+
+<dt><b>4.9.10</b> - <i>March 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.4 (SQLite version 3.45.2)</i><br>
+Disable user authentication extension in build files by default
+
+</dd>
+
+<dt><b>4.9.9</b> - <i>January 2024</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.2 (SQLite version 3.45.0)</i>
+
+</dd>
+
+<dt><b>4.9.8</b> - <i>November 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.0 (SQLite version 3.44.1)</i><br>
+Added new cipher scheme Ascon-128 (Lightweight Authenticated Encryption)
+
+</dd>
+
+<dt><b>4.9.7</b> - <i>November 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.7.4 (SQLite version 3.44.0)</i><br>
+Prevent crashes due to uninitialized cipher tables (issue #113)
+
+</dd>
+
+<dt><b>4.9.6</b> - <i>October 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.7.0 (SQLite version 3.43.1)</i><br>
+
+</dd>
+
+<dt><b>4.9.5</b> - <i>September 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.5 (SQLite version 3.43.1)</i><br>
+
+</dd>
+
+<dt><b>4.9.4</b> - <i>May 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.3 (SQLite version 3.42.0)</i><br>
+
+</dd>
+
 <dt><b>4.9.3</b> - <i>March 2023</i></dt>
 <dd>
 Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.1 (SQLite version 3.41.1)</i><br>
